@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.57 2006/08/11 00:43:13 bowkenken Exp $
+* $Id: amenu.c,v 1.58 2006/09/08 17:58:08 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -725,6 +725,17 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].flg = FLG_NULL;
 		k++;
 
+		sprintf( p[k].path, "%s/edit name", p[kk].path );
+		str_nz_cpy( p[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'N';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT_NAME,
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_auto_mark_edit_name;
+		p[k].arg = (void *)i;
+		p[k].flg = FLG_NULL;
+		k++;
+
 		sprintf( p[k].path, "%s/copy", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = 'W';
@@ -1974,14 +1985,10 @@ char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
 	static char	buf_cmd[MACRO_MAX_LEN + 1];
 	long	x, y;
 
-	/* ȥɽ */
-
-	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_TTL );
-
 	/* Υޥɽ */
 
 	cmd = ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro;
-	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_PREV, cmd );
+	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_TTL, cmd );
 
 	/* ץץȤɽ */
 
@@ -2112,7 +2119,7 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_PASTE );
 
-	return "/auto mark/0";
+	return STR_MENU_CANCEL;
 }
 
 /***************************************************************
@@ -2146,7 +2153,46 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_PASTE );
 
-	return "/edit";
+	return STR_MENU_CANCEL;
+}
+
+/***************************************************************
+* ˥塼̾Խ򤵤줿˸ƤФ
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	static char	info[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	hint[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+
+	n = (long)((*pp)->arg);
+
+	str_nz_cpy( info, get_msg_ttl_auto_mark_info( n ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_nz_cpy( hint, get_msg_ttl_auto_mark_hint( n ),
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	wipe_all();
+	gets_auto_mark_info( info );
+	gets_auto_mark_hint( hint );
+	redraw_all();
+
+	msg_ttl_auto_mark[n][0] = '\0';
+	str_max_n_cat( msg_ttl_auto_mark[n],
+			info,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( msg_ttl_auto_mark[n],
+			STR_TTL_AUTO_MARK_SPLIT_CODE,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_max_n_cat( msg_ttl_auto_mark[n],
+			hint,
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+
+	return "/auto mark";
 }
 
 /***************************************************************
