@@ -5,10 +5,10 @@ extern "C" {
 #endif
 
 bool_t	call_game_thread_create( void *(*func)( void * ) );
+void	call_gui_map_cont_exec_set( bool_t flagExec );
 void	call_gui_menu_draw( draw_menu_t *data );
 void	call_gui_menu_wipe();
 void	call_set_mouse_dflt_menu( long sel_n );
-void	call_all_gtk_init();
 void	call_pcg_dun_reset();
 void	call_pcg_dun_reset_update_flg();
 void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h );
