@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.23 2006/08/14 21:53:55 bowkenken Exp $
+* $Id: call.cpp,v 1.24 2006/08/18 08:00:42 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -60,6 +60,32 @@ bool_t	call_game_thread_create( void *(*func)( void * ) )
 	return TRUE;
 }
 
+/***************************************************************
+* ޥåסɥϢ³¹ԥܥΥå
+* bool_t flagExec : 
+***************************************************************/
+
+void	call_gui_map_cont_exec_set( bool_t flagExec )
+{
+#ifdef D_WS
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+#endif // D_WS
+
+#ifdef D_GTK
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gtk_toggle_button_set_active(
+			GTK_TOGGLE_BUTTON( gMapButtonContExec ),
+			flagExec );
+#endif // D_GTK
+}
+
 /***************************************************************
 * ˥塼ɥ
 * draw_menu_t *data : ˥塼ѥǡ
