@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.100 2006/03/09 23:31:04 bowkenken Exp $
+* $Id: chr.h,v 1.102 2006/09/10 23:53:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -500,7 +500,7 @@ typedef enum {
 	ACT_KIND_SRCH,
 	ACT_KIND_SPELL,
 
-	/* ѡƥΥ*/
+	/* ѡƥΥ */
 	ACT_KIND_SHOP,
 	ACT_KIND_RECALL,
 	ACT_KIND_MAX_N,
@@ -619,6 +619,9 @@ typedef struct {
 
 	/* äԥ */
 	long	dismissal_turn;
+
+	/* 󥹥С̿ϵۼȤä? */
+	bool_t	flg_used_energy_drain;
 } chr_work_t;
 
 /***************************************************************
@@ -738,6 +741,8 @@ typedef struct chr_t {
 	long	x, y;
 	/* ΰ */
 	long	pre_x, pre_y;
+	/* Υΰ */
+	long	pre_turn_x, pre_turn_y;
 	/*  */
 	long	pre_draw_x, pre_draw_y;
 	/*  */
