@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: crsr-ptn.h,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: crsr-ptn.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CRSR_PTN_H
@@ -55,11 +55,11 @@ crsr_ptn_t	crsr_ptn_dflt[] = {
 		},
 	},
 	{
-		+0, +0,
+		-1, +0,
 		0, 0,
 		'@',
 		{
-			"@@<-",
+			"@@@@<-",
 		},
 	},
 };
