@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.26 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: curs.h,v 1.31 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -35,6 +35,7 @@
 * curses Υåѡ
 ***************************************************************/
 
+#include	"extern.h"
 #include	"msg.h"
 
 #if	HAVE_LIBCURSES
@@ -46,13 +47,19 @@
 # include	"curs-def.h"
 #endif	/* HAVE_LIBCURSES */
 
+/***************************************************************
+* 
+***************************************************************/
+
 /* üΥѹ٥ */
 
 #ifndef	KEY_RESIZE
 # define KEY_RESIZE	0632		/* Terminal resize event */
 #endif	/* KEY_RESIZE */
 
-/* ° */
+/***************************************************************
+* °
+***************************************************************/
 
 typedef enum {
 	CURS_ATTR_N_NORMAL,
@@ -65,6 +72,7 @@ typedef enum {
 	CURS_ATTR_N_MAP_MNSTR,
 	CURS_ATTR_N_MAP_NPC,
 	CURS_ATTR_N_MAP_CRSR,
+
 	CURS_ATTR_N_FX_MBR_PLUS,
 	CURS_ATTR_N_FX_MBR_MINUS,
 	CURS_ATTR_N_FX_MBR_CRTCL,
