@@ -112,6 +112,8 @@ void	draw_edit_class(
 	bool_t flg_sel, bool_t flg_sel_add
 );
 bool_t	gets_class_name( char *name );
+bool_t	gets_auto_mark_info( char *name );
+bool_t	gets_auto_mark_hint( char *name );
 bool_t	game_gets( long x, long y, char *s, long len, bool_t flg_pick );
 void	pick_cntrl_str( char *s );
 void	set_crsr( long x, long y );
