@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.11 2006/02/17 05:52:47 bowkenken Exp $
+* $Id: draw-tab.h,v 1.12 2006/09/08 17:58:08 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -493,7 +493,18 @@
 
 /* Edit pet end */
 
-/**/
+/* Edit auto mark begin */
+
+#define	WIN_AUTO_MARK_INFO_TTL_DRAW_MIN_X	0
+#define	WIN_AUTO_MARK_INFO_TTL_DRAW_MIN_Y	0
+
+#define	WIN_AUTO_MARK_HINT_TTL_DRAW_MIN_X	0
+#define	WIN_AUTO_MARK_HINT_TTL_DRAW_MIN_Y	\
+		(WIN_AUTO_MARK_INFO_TTL_DRAW_MIN_Y + 2)
+
+/* Edit auto mark end */
+
+/***************************************************************/
 
 /* СǡΥǥݥȽ */
 
