@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.49 2006/02/17 05:52:47 bowkenken Exp $
+* $Id: draw.h,v 1.50 2006/09/11 22:59:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -122,24 +122,33 @@
 
 typedef unsigned long	flg_msg_t;
 
+/* å */
+#define	FLG_MSG_MES	(1 << 0)
+
+/* ٹ */
+#define	FLG_MSG_WRN	(1 << 1)
+
 /* 顼 */
-#define	FLG_MSG_ERR	(1 << 0)
+#define	FLG_MSG_ERR	(1 << 2)
+
+/* ̿Ū顼 */
+#define	FLG_MSG_FAT	(1 << 3)
+
+/* ǥХåΤɽ */
+#define	FLG_MSG_DEBUG	(1 << 8)
 
 /* ³Ԥ */
-#define	FLG_MSG_MORE	(1 << 1)
+#define	FLG_MSG_MORE	(1 << 16)
 
 /* 1³Ԥ̵ */
-#define	FLG_MSG_NO_MORE_PREV	(1 << 2)
+#define	FLG_MSG_NO_MORE_PREV	(1 << 17)
 
 /* 1ļ³Ԥ̵ */
-#define	FLG_MSG_NO_MORE_NEXT	(1 << 3)
+#define	FLG_MSG_NO_MORE_NEXT	(1 << 18)
 
 /* ³Ԥ̵ */
 #define	FLG_MSG_NO_MORE	(FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT)
 
-/* ǥХåΤɽ */
-#define	FLG_MSG_DEBUG	(1 << 4)
-
 /* åꥹȤɽԿ */
 #define	LS_MSG_DRAW_N	20
 
