@@ -50,6 +50,9 @@ void	make_stairs( long x, long y, char face );
 bool_t	set_statue( long x, long y, long dun_lev, bool_t flg_self );
 void	set_map_total( long x, long y, long dx, long dy );
 void	set_map_total_bg( long x, long y, long dx, long dy );
+void	set_face_from_map_obj(
+	bool_t flg_chk_find, long x, long y, char *mjr, char *mnr
+);
 void	set_map_total_crsr_attr(
 	pos_t *crsr, crsr_ptn_t *ptn, long x, long y, long dx, long dy
 );
@@ -57,7 +60,8 @@ void	set_map_total_obj( long x, long y, long dx, long dy );
 void	set_map_total_square( long x, long y, long dx, long dy );
 void	set_map_total_chr( long x, long y, long dx, long dy );
 void	set_map_total_crsr_ptn(
-	pos_t *crsr, crsr_ptn_t *ptn, long x, long y, long dx, long dy
+	pos_t *crsr, crsr_ptn_t *ptn,
+	long x, long y, long dx, long dy
 );
 void	line_path( long x1, long y1, long x2, long y2, sect_t sect );
 void	put_path( long x, long y, long dx, long dy, sect_t sect );
@@ -108,6 +112,7 @@ bool_t	chk_rate_hide_cross_path( long dun_lev );
 char	get_chr_mjr_crsr( void );
 char	get_chr_mnr_crsr( void );
 char	get_chr_crsr( bool_t flg_mjr );
+long	chk_nest_flg_dun( void );
 bool_t	save_dun( void );
 
 #ifdef __cplusplus
