@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.93 2006/01/15 01:11:03 bowkenken Exp $
+* $Id: dun.c,v 1.94 2006/02/04 08:11:47 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -671,9 +671,7 @@ void	make_dun( void )
 
 	/* ȥå */
 
-	for( y = 0; y < AREA_MAP_MAX_Y; y++ )
-		for( x = 0; x < AREA_MAP_MAX_X; x++ )
-			make_trap_room( x, y, dun.lev );
+	make_chk_trap_room( dun.lev );
 
 	if( flg_boss ){
 		curs_attrset_chr( get_mbr_randm( MAP_DEL_X, MAP_DEL_Y ),
