@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.115 2006/01/27 16:25:25 bowkenken Exp $
+* $Id: fight.c,v 1.117 2006/08/10 21:33:18 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,12 +43,13 @@
 
 /* ٥뤬㤤ۤɶ */
 /* ٥뤬夬о夬ۤɺ̵ʤ */
-#define	FLG_ITEM_ADD_RATE
+#define	FLG_ITEM_ADD_RATE	1
 
 #else
 
 /* ٥뤬㤤Ϻ̵ */
 /* ٥뤬夬о夬ۤɶϤˤʤ */
+#define	FLG_ITEM_ADD_RATE	0
 
 #endif
 
@@ -88,11 +89,11 @@
 
 /* ˡξι */
 #define	DAM_STICK_RATE	((rate_t)120)
-#define	DAM_STICK_ADD	2
+#define	DAM_STICK_ADD	10
 
 /* ʸι */
 #define	DAM_SPELL_RATE	((rate_t)150)
-#define	DAM_SPELL_ADD	2
+#define	DAM_SPELL_ADD	10
 
 /* ֥Ȥɸ */
 #define	DOOR_DEF	12
@@ -895,18 +896,18 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 
 	/* ¦̾μ */
 
-	strncpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
 
 	/* ɸ¦̾ȥǡμ */
 
 	if( flg_d_null ){
-		strncpy( d_name, MSG_NULL, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_LEN );
 		d_hp = NULL;
 		d_fx = NULL;
 		d_x = 0;
 		d_y = 0;
 	} else {
-		strncpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
 		d_hp = &(d_p->abl.hp);
 		d_fx = &(d_p->fx);
 		d_x = d_p->x;
@@ -1276,13 +1277,13 @@ bool_t	spell_attack(
 	o_stat = o_p->stat;
 	o_pos.x = o_p->x;
 	o_pos.y = o_p->y;
-	strncpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
 
 	/* ɸ¦ǡ */
 
 	d_pos.x = d_p->x;
 	d_pos.y = d_p->y;
-	strncpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
 
 	/* Ǥ뤫 */
 
