@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fx.h,v 1.47 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: fx.h,v 1.48 2006/02/17 04:45:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FX_H
@@ -101,6 +101,8 @@
 #define	FX_AVE_TURN_SPEED_UP	256
 #define	FX_AVE_TURN_SPEED_DOWN	256
 
+#define	FX_AVE_TURN_STORE_LIGHT	FX_TURN_INFINITE_N
+
 #define	FX_AVE_TURN_DARKVISION	128
 #define	FX_AVE_TURN_RECALL	20
 
@@ -168,6 +170,7 @@ typedef enum {
 	FX_KIND_SPEED_UP,
 	FX_KIND_SPEED_DOWN,
 	FX_KIND_BLESS,
+	FX_KIND_STORE_LIGHT,
 	FX_KIND_MAX_N,
 } fx_kind_t;
 
