@@ -91,6 +91,8 @@ char	*cb_menu_avoid_trap( menu_t **pp, menu_t **dflt );
 char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
 char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
 char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
+char	*cb_menu_reset_file_config( menu_t **pp, menu_t **dflt );
+char	*cb_menu_reset_file_town_ptn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_lang( menu_t **pp, menu_t **dflt );
 char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt );
 char	*cb_menu_lang_ls_sel( menu_t **pp, menu_t **dflt );
