@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.8 2006/08/16 23:41:48 bowkenken Exp $
+* $Id: imenu.c,v 1.12 2006/09/12 01:25:21 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -111,6 +111,9 @@ bool_t	set_continue_exec_mode( void )
 {
 	g_flg_continue_exec_mode = TRUE;
 
+	call_gui_map_cont_exec_set(
+			g_flg_continue_exec_mode );
+
 	return g_flg_continue_exec_mode;
 }
 
@@ -120,6 +123,9 @@ bool_t	clr_continue_exec_mode( void )
 {
 	g_flg_continue_exec_mode = FALSE;
 
+	call_gui_map_cont_exec_set(
+			g_flg_continue_exec_mode );
+
 	return g_flg_continue_exec_mode;
 }
 
@@ -2514,6 +2520,44 @@ char	*cb_menu_space_select( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_reset_file_config( menu_t **pp, menu_t **dflt )
+{
+	ask_t	ask;
+
+	ask = exec_menu_ask( MSG_TTL_MENU_RESET_FILE_ASK, ASK_NO, TRUE );
+
+	if( ask == ASK_ERR )
+		return STR_MENU_ERR;
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	back_up_game_conf();
+	print_msg( FLG_MSG_WRN, MSG_RESET_FILE );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_reset_file_town_ptn( menu_t **pp, menu_t **dflt )
+{
+	ask_t	ask;
+
+	ask = exec_menu_ask( MSG_TTL_MENU_RESET_FILE_ASK, ASK_NO, TRUE );
+
+	if( ask == ASK_ERR )
+		return STR_MENU_ERR;
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	back_up_town_ptn();
+	print_msg( FLG_MSG_WRN, MSG_RESET_FILE );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_lang( menu_t **pp, menu_t **dflt )
 {
 	if( get_flg_lang_ls_priority() )
