@@ -72,6 +72,7 @@ void	init_food( void );
 void	init_tobacco( void );
 void	init_pipe( void );
 void	init_rare_goods( void );
+void	init_bone( void );
 void	init_coin( void );
 void	reset_item_town( void );
 void	clr_dun_item( void );
@@ -125,6 +126,8 @@ item_t	*make_item_disposal_rand( long dun_lev );
 item_t	*make_item_disposal( long dun_lev );
 item_t	*make_item_rare_goods_rand( long dun_lev );
 item_t	*make_item_rare_goods( long dun_lev, long n );
+item_t	*make_item_bone_rand( long dun_lev );
+item_t	*make_item_bone( long dun_lev, mnstr_tab_t *tab );
 item_t	*make_item_coin_rand( long dun_lev );
 item_t	*make_item_coin( long dun_lev, long n );
 item_t	*make_item_junk_rand( long dun_lev );
@@ -152,10 +155,9 @@ void	set_item_name_tobacco( item_t *item );
 void	set_item_name_pipe( item_t *item );
 void	set_item_name_disposal( item_t *item );
 void	set_item_name_rare_goods( item_t *item );
+void	set_item_name_bone( item_t *item );
 void	set_item_name_coin( item_t *item );
 void	set_item_name_junk( item_t *item );
-char	*get_str_can_use_item( mbr_t *mbr, item_t *item );
-can_use_item_t	chk_can_use_item( mbr_t *mbr, item_t *item );
 void	clean_all_disposal( mbr_t *mbr );
 bool_t	identify_item( item_t *item );
 bool_t	identify_potion( item_t *item );
@@ -179,7 +181,7 @@ bool_t	chk_singly_equip( item_t *item, equip_kind_t kind );
 bool_t	chk_equip_two_handed_wpn(
 	mbr_t *mbr, item_t *item, equip_kind_t kind
 );
-bool_t	chk_inst_limit( chr_t *chr );
+bool_t	chk_bar_limit_inst( chr_t *chr );
 bool_t	chk_equip_kind( item_t *item, equip_kind_t kind );
 bool_t	take_off_item( mbr_t *mbr, equip_kind_t kind );
 bool_t	take_off_item_sub( mbr_t *mbr, equip_kind_t kind );
@@ -297,6 +299,7 @@ spell_kind_t	get_inst_spell_kind( mbr_t *mbr );
 rate_t	add_hit( long n );
 rate_t	add_wpn_crtcl( long n );
 rate_t	add_dam( long n );
+rate_t	add_dam_two_handed_wpn( mbr_t *mbr, item_t *wpn );
 rate_t	add_def( long n );
 rate_t	add_armor_crtcl( long n );
 rate_t	add_ac( long n );
@@ -330,6 +333,8 @@ item_t	*get_item_own(
 item_t	*get_item_food(
 	chr_t *chr, act_kind_t act_kind, bool_t flg_auto_menu
 );
+item_t	*randm_wpn( item_t *eq );
+item_t	*randm_armor( item_t *eq );
 bool_t	chk_mark_item( item_t *p, act_kind_t act_kind );
 bool_t	chk_own_item( item_t *item, mbr_t *mbr );
 bool_t	chk_appoint_item( item_t *item, mbr_t *mbr );
