@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.84 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: item.h,v 1.85 2006/09/15 09:38:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -44,6 +44,9 @@
 #define	MBR_ITEM_MAX_N	16
 /* µܤƤʿѿ */
 #define	DUN_ITEM_AVE_N	16
+/* Ƥʿѿ */
+#define	DUN_ITEM_TRAP_ROOM_AVE_N	4
+
 /* ƥ̾κʸ */
 #define	ITEM_NAME_MAX_LEN	60
 /* ʤΥƥ̾κʸ */
