@@ -1,4 +1,4 @@
-#! /bin/sh
+#!/bin/sh
 
 #### Set locale ####
 
@@ -15,4 +15,4 @@ export LANG
 
 #### Start game ####
 
-./lnl
+./lnl $*
