@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.8 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: main-dos.c,v 1.9 2006/09/06 23:04:23 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -58,14 +58,19 @@
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"c:p:e:m:Vh"
+#define	STR_OPT	"gcuk:e:s:p:md:Vh"
 
 #if	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
-	{ "clear-key-buf", required_argument, NULL, 'c' },
-	{ "use-keypad",    required_argument, NULL, 'p' },
+	{ "gui",           no_argument,       NULL, 'g' },
+	{ "cui",           no_argument,       NULL, 'c' },
+	{ "gui-and-cui",   no_argument,       NULL, 'u' },
+	{ "clear-key-buf", required_argument, NULL, 'k' },
 	{ "echo-key",      required_argument, NULL, 'e' },
-	{ "measure-clock", required_argument, NULL, 'm' },
+	{ "use-curses",    required_argument, NULL, 's' },
+	{ "use-keypad",    required_argument, NULL, 'p' },
+	{ "measure-clock", no_argument,       NULL, 'm' },
+	{ "debug",         required_argument, NULL, 'd' },
 	{ "version",       no_argument,       NULL, 'V' },
 	{ "help",          no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
@@ -76,19 +81,30 @@ static struct option	long_opt[] = {
 * 
 ***************************************************************/
 
-#define	STR_USAGE	\
-	"Usage: %s [OPTION]...\n" \
-	"OPTION:\n" \
-	"  -c, --clear-key-buf=FLAG clear key buffer:\n" \
-	"                             ON, OFF\n" \
-	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n" \
-	"                             ON, OFF\n" \
-	"  -e, --echo-key=FLAG      echo key:\n" \
-	"                             ON, OFF\n" \
-	"  -m, --measure-clock=FLAG measure CLK_TCK:\n" \
-	"                             ON, OFF\n" \
-	"  -V, --version            display version and exit\n" \
+char	str_usage[] = {
+	"Usage: %s [OPTION]...\n"
+	"OPTION:\n"
+#if	0
+	"  -g, --gui                set GUI mode\n"
+	"  -c, --cui                set CUI mode\n"
+	"  -u, --gui-and-cui        set GUI and CUI mode\n"
+#endif
+	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
+	"                             ON, OFF\n"
+	"  -e, --echo-key=FLAG      echo key:\n"
+	"                             ON, OFF\n"
+	"  -s, --use-curses=FLAG    use curses library:\n"
+	"                             ON, OFF\n"
+	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
+	"                             ON, OFF\n"
+	"  -m, --measure-clock      measure frame rate\n"
+#if	0
+	"  -d, --debug=FLAG         set debug mode:\n"
+	"                             ON, OFF\n"
+#endif
+	"  -V, --version            display version and exit\n"
 	"  -h, --help               display this help and exit\n"
+};
 
 /***************************************************************
 * ѿ
@@ -121,6 +137,9 @@ int	main_dos( void )
 
 void	chk_arg( int argc, char **argv )
 {
+	if( argv == NULL )
+		return;
+
 #if	HAVE_GETOPT || HAVE_GETOPT_LONG
 	while( 1 ){
 		long	c;
@@ -135,18 +154,36 @@ void	chk_arg( int argc, char **argv )
 		if( c <= -1 )
 			break;
 		switch( c ){
+		case 'g':
+			g_flg_cui = FALSE;
+			g_flg_gui = TRUE;
+			break;
 		case 'c':
-			g_flg_clr_key_buf = chk_opt_flg( optarg );
-			g_flg_clr_key_buf_menu = g_flg_clr_key_buf;
+			g_flg_cui = TRUE;
+			g_flg_gui = FALSE;
+			break;
+		case 'u':
+			g_flg_cui = TRUE;
+			g_flg_gui = TRUE;
+			break;
+		case 'k':
+			g_flg_clr_key_buf_arg_overwrite = TRUE;
+			g_flg_clr_key_buf_arg = chk_opt_flg( optarg );
+			break;
+		case 'e':
+			g_flg_echo_key = chk_opt_flg( optarg );
+			break;
+		case 's':
+			g_flg_use_curs = chk_opt_flg( optarg );
 			break;
 		case 'p':
 			g_flg_use_keypad = chk_opt_flg( optarg );
 			break;
 		case 'm':
-			g_flg_measure_clk_tck = chk_opt_flg( optarg );
+			g_flg_measure_clk_tck = TRUE;
 			break;
-		case 'e':
-			g_flg_echo_key = chk_opt_flg( optarg );
+		case 'd':
+			g_flg_debug = chk_opt_flg( optarg );
 			break;
 		case 'V':
 			version( stdout );
@@ -220,6 +257,18 @@ bool_t	chk_opt_flg( const char *optarg )
 	return FALSE;
 }
 
+/***************************************************************
+* ǻꤵ줿
+***************************************************************/
+
+void	overwrite_arg()
+{
+	if( g_flg_clr_key_buf_arg_overwrite ){
+		g_flg_clr_key_buf = g_flg_clr_key_buf_arg;
+		g_flg_clr_key_buf_menu = g_flg_clr_key_buf_arg;
+	}
+}
+
 /***************************************************************
 * ɽ
 * FILE *fp : ե
@@ -230,7 +279,7 @@ void	usage( FILE *fp )
 	if( !g_flg_cui )
 		return;
 
-	fprintf( fp, STR_USAGE, STR_FILE_NAME_GAME );
+	fprintf( fp, str_usage, STR_FILE_NAME_GAME );
 	fflush( fp );
 }
 
