@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.182 2006/08/13 20:02:58 bowkenken Exp $
+* $Id: menu.c,v 1.183 2006/09/06 23:04:23 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -1071,7 +1071,7 @@ void	wait_key_ex( bool_t flg_exec_key, bool_t flg_can_move_crsr )
 
 	while( 1 ){
 		if( flg_can_move_crsr )
-			c = chk_key( TRUE, FALSE );
+			c = chk_key( g_flg_clr_key_buf, FALSE );
 		else
 			c = get_key( g_flg_clr_key_buf );
 
