@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.36 2006/08/11 00:43:13 bowkenken Exp $
+* $Id: misc.c,v 1.37 2006/09/07 00:30:28 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -294,125 +294,6 @@ bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat )
 	return TRUE;
 }
 
-/***************************************************************
-* ʸɽʸ֤
-* const char *s : ʸ
-* return : ʸ
-***************************************************************/
-
-long	str_len_draw( const char *s )
-{
-#ifdef	D_DOS
-
-	return( (long)strlen( s ) );
-
-#else	/* D_DOS */
-
-	switch( get_lang_kind() ){
-	case LANG_KIND_ENGLISH:
-		return str_len_draw_english( s );
-	case LANG_KIND_JAPANESE_EUC:
-		return str_len_draw_japanese_euc( s );
-	case LANG_KIND_JAPANESE_UTF_8:
-		return str_len_draw_japanese_utf_8( s );
-	case LANG_KIND_MAX_N:
-		break;
-	}
-
-	return( (long)strlen( s ) );
-
-#endif	/* D_DOS */
-}
-
-/***************************************************************
-* Ѹʸɽʸ֤
-* const char *s : ʸ
-* return : ʸ
-***************************************************************/
-
-long	str_len_draw_english( const char *s )
-{
-#if	1
-/*@@@*/
-	return str_len_draw_japanese_euc( s );
-#else
-	return( (long)strlen( s ) );
-#endif
-}
-
-/***************************************************************
-* ܸ(EUC)ʸɽʸ֤
-* const char *s : ʸ
-* return : ʸ
-***************************************************************/
-
-long	str_len_draw_japanese_euc( const char *s )
-{
-	long	len;
-
-	for( len = 0; *s; len++, s++ ){
-		unsigned char	c;
-
-		c = (unsigned char)*s;
-		if( (0x80 <= c) && (c <= 0x9f) )
-			len--;
-	}
-
-	return len;
-}
-
-/***************************************************************
-* ܸ(UTF-8)ʸɽʸ֤
-* const char *s : ʸ
-* return : ʸ
-***************************************************************/
-
-long	str_len_draw_japanese_utf_8( const char *s )
-{
-	long	len;
-	unsigned char	c;
-	long	skip_n;
-	long	i;
-
-	len = 0;
-	for( ; *s != '\0'; s++ ){
-		c = (unsigned char)*s;
-		skip_n = 0;
-
-		if( (c & 0x80) == 0x00 ){
-			len++;
-			continue;
-		} else if( (c & 0xe0) == 0xc0 ){
-			skip_n = 2;
-		} else if( (c & 0xf0) == 0xe0 ){
-			skip_n = 3;
-		} else if( (c & 0xf8) == 0xf0 ){
-			skip_n = 4;
-		} else if( (c & 0xfc) == 0xf8 ){
-			skip_n = 5;
-		} else if( (c & 0xfe) == 0xfc ){
-			skip_n = 6;
-		}
-
-		len += 2;
-		s++;
-		for( i = 1; i < skip_n; i++ ){
-			if( *s == '\0' ){
-				s--;
-				break;
-			}
-			if( (c & 0xc0) != 0x80 ){
-				s--;
-				break;
-			}
-
-			s++;
-		}
-	}
-
-	return len;
-}
-
 /***************************************************************
 * ʸΥ꡼ʸ֤
 * const char *s : ʸ
