@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.10 2006/08/16 23:41:48 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.12 2006/09/11 22:59:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -603,6 +603,33 @@ menu_t	ls_menu_main[] = {
 		cb_menu_space_select, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/reset file",
+		"<Branch>",
+		'R',
+		"",
+		N_MSG_MENU_RESET_FILE, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/reset file/config",
+		"<Item>",
+		'C',
+		"",
+		N_MSG_MENU_RESET_FILE_CONFIG, "",
+		cb_menu_reset_file_config, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/reset file/town ptn",
+		"<Item>",
+		'T',
+		"",
+		N_MSG_MENU_RESET_FILE_TOWN_PTN, "",
+		cb_menu_reset_file_town_ptn, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/lang",
 		"<Branch>",
@@ -639,8 +666,18 @@ menu_t	ls_menu_main[] = {
 		cb_menu_lang_ls_priority, NULL,
 		FLG_NULL,
 	},
+/*  begin */
 	{
-		"/misc/config/window",
+		"/misc/config/screen",
+		"<Branch>",
+		'V',
+		"",
+		N_MSG_MENU_SCREEN, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window",
 		"<Branch>",
 		'W',
 		"",
@@ -649,7 +686,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/title",
+		"/misc/config/screen/window/title",
 		"<Title>",
 		'\0',
 		"",
@@ -658,7 +695,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/scroll",
+		"/misc/config/screen/window/scroll",
 		"<Branch>",
 		'S',
 		"",
@@ -667,7 +704,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/scroll/page",
+		"/misc/config/screen/window/scroll/page",
 		"<RadioItem>",
 		'P',
 		"",
@@ -676,7 +713,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/scroll/smooth",
+		"/misc/config/screen/window/scroll/smooth",
 		"<RadioItem>",
 		'S',
 		"",
@@ -685,7 +722,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/scroll/center",
+		"/misc/config/screen/window/scroll/center",
 		"<RadioItem>",
 		'C',
 		"",
@@ -694,7 +731,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/redraw every turn",
+		"/misc/config/screen/window/redraw every turn",
 		"<CheckItem>",
 		'D',
 		"",
@@ -703,7 +740,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/window/multi message",
+		"/misc/config/screen/window/multi message",
 		"<CheckItem>",
 		'M',
 		"",
@@ -713,7 +750,7 @@ menu_t	ls_menu_main[] = {
 	},
 /* VFX begin */
 	{
-		"/misc/config/vfx",
+		"/misc/config/screen/vfx",
 		"<Branch>",
 		'X',
 		"",
@@ -722,7 +759,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/title",
+		"/misc/config/screen/vfx/title",
 		"<Title>",
 		'\0',
 		"",
@@ -731,7 +768,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/member cure",
+		"/misc/config/screen/vfx/member cure",
 		"<CheckItem>",
 		'A',
 		"",
@@ -740,7 +777,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/member dam",
+		"/misc/config/screen/vfx/member dam",
 		"<CheckItem>",
 		'B',
 		"",
@@ -749,7 +786,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/member critical",
+		"/misc/config/screen/vfx/member critical",
 		"<CheckItem>",
 		'C',
 		"",
@@ -758,7 +795,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/member arrow",
+		"/misc/config/screen/vfx/member arrow",
 		"<CheckItem>",
 		'D',
 		"",
@@ -767,7 +804,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/monster cure",
+		"/misc/config/screen/vfx/monster cure",
 		"<CheckItem>",
 		'E',
 		"",
@@ -776,7 +813,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/monster dam",
+		"/misc/config/screen/vfx/monster dam",
 		"<CheckItem>",
 		'F',
 		"",
@@ -785,7 +822,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/monster critical",
+		"/misc/config/screen/vfx/monster critical",
 		"<CheckItem>",
 		'G',
 		"",
@@ -794,7 +831,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/monster arrow",
+		"/misc/config/screen/vfx/monster arrow",
 		"<CheckItem>",
 		'H',
 		"",
@@ -803,7 +840,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/wait",
+		"/misc/config/screen/vfx/wait",
 		"<OpenWinItem>",
 		'W',
 		"",
@@ -812,7 +849,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/vfx/measure clock",
+		"/misc/config/screen/vfx/measure clock",
 		"<Item>",
 		'X',
 		"",
@@ -822,7 +859,7 @@ menu_t	ls_menu_main[] = {
 	},
 /* VFX end */
 	{
-		"/misc/config/color",
+		"/misc/config/screen/color",
 		"<Branch>",
 		'C',
 		"",
@@ -831,7 +868,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/cursor pattern",
+		"/misc/config/screen/cursor pattern",
 		"<Branch>",
 		'V',
 		"",
@@ -839,6 +876,7 @@ menu_t	ls_menu_main[] = {
 		cb_menu_crsr_ptn, NULL,
 		FLG_NULL,
 	},
+/*  end */
 	{
 		"/misc/config/key",
 		"<Branch>",
