@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.11 2006/08/12 04:22:56 bowkenken Exp $
+* $Id: mmenu.c,v 1.12 2006/09/06 23:04:23 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -240,7 +240,7 @@ char	*exec_menu_point_crsr( void )
 	while( 1 ){
 		long	c;
 
-		c = chk_key( TRUE, FALSE );
+		c = chk_key( g_flg_clr_key_buf, FALSE );
 		switch( c ){
 		case CASE_CANCEL:
 			return STR_MENU_CANCEL;
