@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.12 2006/01/15 13:33:45 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.13 2006/02/17 22:38:38 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -86,7 +86,7 @@ void	set_act_mnstr_std( mnstr_t *p )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
@@ -112,7 +112,7 @@ void	set_act_mnstr_cubus( mnstr_t *p, sex_t sex )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
@@ -344,11 +344,11 @@ bool_t	set_act_tame_mnstr( mnstr_t *p )
 	} else {
 		/* ʢäѤˤʤä */
 
-		if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+		if( chk_flg_work_find_mbr( p ) )
 			return FALSE;
 
 		mnstr_mark_mbr_std( p );
-		if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+		if( chk_flg_work_find_mbr( p ) ){
 			/* ã */
 			chk_finish_request_join( p->work.request, p );
 		}
@@ -372,12 +372,12 @@ bool_t	set_act_rescue_trgt( mnstr_t *p )
 	if( p->work.request->kind != REQUEST_KIND_RESCUE )
 		return FALSE;
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		return FALSE;
 
 	mnstr_mark_mbr_std( p );
 
-	if( !chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( !chk_flg_work_find_mbr( p ) )
 		return TRUE;
 
 	/* ߽λ */
@@ -535,7 +535,7 @@ void	set_act_mnstr_venus_fly_trap( mnstr_t *p )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
@@ -640,7 +640,7 @@ void	set_act_mnstr_giant_spider( mnstr_t *p )
 
 	/* СȯƤ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+	if( chk_flg_work_find_mbr( p ) ){
 		/* С */
 		if( flg_rel )
 			release_chr( p );
@@ -706,7 +706,7 @@ void	set_act_mnstr_gigantic_centipede( mnstr_t *p )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
@@ -726,7 +726,7 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 	if( p == NULL )
 		return;
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) ){
+	if( chk_flg_work_find_mbr( p ) ){
 		/* СȯƤ̤˥ޡ */
 
 		mnstr_mark_mbr_std( p );
@@ -754,7 +754,7 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
@@ -775,7 +775,7 @@ void	set_act_mnstr_mimic( mnstr_t *p )
 
 	/* СȯƤϹ⤹ */
 
-	if( chk_flg( p->work.flg, FLG_WORK_FIND_MBR ) )
+	if( chk_flg_work_find_mbr( p ) )
 		mnstr_move_or_atack_std( p );
 }
 
