@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,13 +25,17 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-kind.h,v 1.2 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: mnstr-kind.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_KIND_H
 #define	MNSTR_KIND_H
 
-/* 󥹥μꥹ */
+/***************************************************************
+* 󥹥μ
+***************************************************************/
+
+/* 󥹥μΥꥹ */
 
 typedef enum {
 	MNSTR_KIND_NULL,
@@ -192,15 +196,21 @@ typedef enum {
 	MNSTR_KIND_MAX_N,
 } mnstr_kind_t;
 
-/***************************************************************/
+/***************************************************************
+* 󥹥δ
+***************************************************************/
 
-/* 󥹥δ */
+/*  */
+
+#define	FACE_MJR_MNSTR_GOD	'+'
 
-#define	FACE_MJR_MNSTR_GOD	'+'		/*  */
 #define	FACE_MNR_MNSTR_COATL	'c'		/*@@@*/
 #define	FACE_MNR_MNSTR_NAGA	'n'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_DRAGON	'D'		/* ɥ饴 */
+/* ɥ饴 */
+
+#define	FACE_MJR_MNSTR_DRAGON	'D'
+
 /* Ancient dragon */
 #define	FACE_MNR_MNSTR_A_GOLD_DRAGON	'G'	/* RESI_KIND_SLAS,· */
 #define	FACE_MNR_MNSTR_A_SILVER_DRAGON	'S'	/* RESI_KIND_KNOC, */
@@ -222,20 +232,29 @@ typedef enum {
 #define	FACE_MNR_MNSTR_M_WHITE_DRAGON	'w'	/* RESI_KIND_ELEC, */
 #define	FACE_MNR_MNSTR_M_BLACK_DRAGON	'k'	/* RESI_KIND_POIS, */
 
-#define	FACE_MJR_MNSTR_ILLUSORY	'L'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_ILLUSORY	'L'
+
 #define	FACE_MNR_MNSTR_PHOENIX	'x'
 #define	FACE_MNR_MNSTR_UNICORN	'u'
 #define	FACE_MNR_MNSTR_PEGASUS	'p'		/*@@@*/
 #define	FACE_MNR_MNSTR_PYON_PYON	'p'
 
-#define	FACE_MJR_MNSTR_FAIRY	'F'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_FAIRY	'F'
+
 #define	FACE_MNR_MNSTR_PIXY	'p'		/*@@@*/
 #define	FACE_MNR_MNSTR_SPRITE	's'		/*@@@*/
 #define	FACE_MNR_MNSTR_DRYAD	'd'		/*@@@*/
 #define	FACE_MNR_MNSTR_BROWNIE	'b'		/*@@@*/
 #define	FACE_MNR_MNSTR_LEPRECHAUN	'l'
 
-#define	FACE_MJR_MNSTR_ELEMENTAL	'E'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_ELEMENTAL	'E'
+
 #define	FACE_MNR_MNSTR_FIRE_ELEMENTAL	'f'
 #define	FACE_MNR_MNSTR_SALAMANDER	's'
 #define	FACE_MNR_MNSTR_WATER_ELEMENTAL	'w'
@@ -247,14 +266,20 @@ typedef enum {
 #define	FACE_MNR_MNSTR_WILL_O_WISP	'o'
 #define	FACE_MNR_MNSTR_SHADE	'd'
 
-#define	FACE_MJR_MNSTR_PLANT	'P'		/* ʪ */
+/* ʪ */
+
+#define	FACE_MJR_MNSTR_PLANT	'P'
+
 #define	FACE_MNR_MNSTR_VENUS_FLY_TRAP	'f'
 #define	FACE_MNR_MNSTR_SLIME	's'
 #define	FACE_MNR_MNSTR_SPORE	'p'
 #define	FACE_MNR_MNSTR_MANDRAKE	'm'		/*@@@*/
 #define	FACE_MNR_MNSTR_TREANT	't'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_ANIMAL	'A'		/* ưʪ */
+/* ưʪ */
+
+#define	FACE_MJR_MNSTR_ANIMAL	'A'
+
 #define	FACE_MNR_MNSTR_BAT	'b'
 #define	FACE_MNR_MNSTR_RAT	'r'
 #define	FACE_MNR_MNSTR_SNAKE	's'
@@ -267,7 +292,10 @@ typedef enum {
 #define	FACE_MNR_MNSTR_BEAR	'a'		/*@@@*/
 #define	FACE_MNR_MNSTR_HORSE	'h'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_INSECT	'I'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_INSECT	'I'
+
 #define	FACE_MNR_MNSTR_CENTIPEDE	'c'
 #define	FACE_MNR_MNSTR_BEE	'b'
 #define	FACE_MNR_MNSTR_SCORPION	'p'
@@ -276,7 +304,10 @@ typedef enum {
 #define	FACE_MNR_MNSTR_FLY	'f'
 #define	FACE_MNR_MNSTR_BEETLE	't'
 
-#define	FACE_MJR_MNSTR_HUMAN	'H'		/* ʹ֡ʹ */
+/* ʹ֡ʹ */
+
+#define	FACE_MJR_MNSTR_HUMAN	'H'
+
 #define	FACE_MNR_MNSTR_FIGHTER	'f'
 #define	FACE_MNR_MNSTR_MONK	'm'
 #define	FACE_MNR_MNSTR_HUNTER	'h'
@@ -294,7 +325,12 @@ typedef enum {
 #define	FACE_MNR_MNSTR_CRAFTSMAN	'u'
 #define	FACE_MNR_MNSTR_MERCHANT	'u'
 
-#define	FACE_MJR_MNSTR_HYBRID	'Y'		/* Ⱦ */
+/* Ⱦ */
+
+#define	FACE_MJR_MNSTR_HYBRID	'Y'
+
+#define	FACE_MNR_MNSTR_GREAT_MINOTAUR	'M'
+#define	FACE_MNR_MNSTR_MEDUSA_ZOMBIE	'D'
 #define	FACE_MNR_MNSTR_HARPY	'h'
 #define	FACE_MNR_MNSTR_ANDRO_SCORPION	's'
 #define	FACE_MNR_MNSTR_LAMIA	'l'
@@ -309,10 +345,11 @@ typedef enum {
 #define	FACE_MNR_MNSTR_SIREN	'r'		/*@@@*/
 #define	FACE_MNR_MNSTR_SCYLLA	'y'		/*@@@*/
 #define	FACE_MNR_MNSTR_SATYR	'a'		/*@@@*/
-#define	FACE_MNR_MNSTR_GREAT_MINOTAUR	'M'
-#define	FACE_MNR_MNSTR_MEDUSA_ZOMBIE	'D'
 
-#define	FACE_MJR_MNSTR_GIANT	'G'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_GIANT	'G'
+
 #define	FACE_MNR_MNSTR_HIGH_RE_HOO	'H'
 #define	FACE_MNR_MNSTR_YETI	'y'
 #define	FACE_MNR_MNSTR_OGRE	'o'
@@ -325,19 +362,28 @@ typedef enum {
 #define	FACE_MNR_MNSTR_CYCLOPS	'c'
 #define	FACE_MNR_MNSTR_HUMBABA	'b'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_HUGE	'B'		/* ʪ */
+/* ʪ */
+
+#define	FACE_MJR_MNSTR_HUGE	'B'
+
+#define	FACE_MNR_MNSTR_GIGANTIC_CENTIPEDE	'C'
 #define	FACE_MNR_MNSTR_WORM	'w'		/*@@@*/
 #define	FACE_MNR_MNSTR_DINOSAUR	'd'		/*@@@*/
 #define	FACE_MNR_MNSTR_ROC	'r'		/*@@@*/
-#define	FACE_MNR_MNSTR_GIGANTIC_CENTIPEDE	'C'
 
-#define	FACE_MJR_MNSTR_AQUATIC	'Q'		/* ʪ */
+/* ʪ */
+
+#define	FACE_MJR_MNSTR_AQUATIC	'Q'
+
 #define	FACE_MNR_MNSTR_KRAKEN	'k'		/*@@@*/
 #define	FACE_MNR_MNSTR_SEA_SERPENT	's'		/*@@@*/
 #define	FACE_MNR_MNSTR_MERMAN	'm'		/*@@@*/
 #define	FACE_MNR_MNSTR_MERMAID	'w'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_MAGICAL	'M'		/* ˡʪ */
+/* ˡʪ */
+
+#define	FACE_MJR_MNSTR_MAGICAL	'M'
+
 #define	FACE_MNR_MNSTR_INVISIBLE_STALKER	'v'
 #define	FACE_MNR_MNSTR_GARGOYLE	'g'
 #define	FACE_MNR_MNSTR_MIMIC	'&'
@@ -349,13 +395,20 @@ typedef enum {
 #define	FACE_MNR_MNSTR_GAS_CLOUD	'c'
 #define	FACE_MNR_MNSTR_HOMUNCULUS	'h'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_COMPOUND	'C'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_COMPOUND	'C'
+
 #define	FACE_MNR_MNSTR_HIPPOGRIFF	'h'
 #define	FACE_MNR_MNSTR_GRIFFON	'g'
 #define	FACE_MNR_MNSTR_MANTICORE	'm'
 #define	FACE_MNR_MNSTR_CHIMERA	'c'
 
-#define	FACE_MJR_MNSTR_UNDEAD	'U'		/* ǥå */
+/* ǥå */
+
+#define	FACE_MJR_MNSTR_UNDEAD	'U'
+
+#define	FACE_MNR_MNSTR_VAMPIRE_LORD	'V'
 #define	FACE_MNR_MNSTR_POLTERGEIST	'p'
 #define	FACE_MNR_MNSTR_SKELETON	's'
 #define	FACE_MNR_MNSTR_ZOMBIE	'z'
@@ -369,9 +422,11 @@ typedef enum {
 #define	FACE_MNR_MNSTR_VAMPIRE	'v'
 #define	FACE_MNR_MNSTR_SPIRIT	't'
 #define	FACE_MNR_MNSTR_DOPPELGANGER	'd'		/*@@@*/
-#define	FACE_MNR_MNSTR_VAMPIRE_LORD	'V'
 
-#define	FACE_MJR_MNSTR_EVIL	'V'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_EVIL	'V'
+
 #define	FACE_MNR_MNSTR_KOBOLD	'k'
 #define	FACE_MNR_MNSTR_GOBLIN	'g'
 #define	FACE_MNR_MNSTR_GREMLIN	'm'
@@ -383,7 +438,10 @@ typedef enum {
 #define	FACE_MNR_MNSTR_EFREET	'e'
 #define	FACE_MNR_MNSTR_DJINNI	'j'
 
-#define	FACE_MJR_MNSTR_EVIL_BEAST	'W'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_EVIL_BEAST	'W'
+
 #define	FACE_MNR_MNSTR_BLACK_UNICORN	'U'
 #define	FACE_MNR_MNSTR_RUST_MONSTER	'r'
 #define	FACE_MNR_MNSTR_HELLHOUND	'h'
@@ -395,12 +453,15 @@ typedef enum {
 #define	FACE_MNR_MNSTR_BASILISK	'b'
 #define	FACE_MNR_MNSTR_BEHOLDER	'e'		/*@@@*/
 
-#define	FACE_MJR_MNSTR_DEVIL	'X'		/*  */
+/*  */
+
+#define	FACE_MJR_MNSTR_DEVIL	'X'
+
 #define	FACE_MNR_MNSTR_IMP	'i'
 #define	FACE_MNR_MNSTR_JACK_O_LANTERN	'j'
 #define	FACE_MNR_MNSTR_MIND_FLAYER	'm'		/*@@@*/
 #define	FACE_MNR_MNSTR_BEHEMOTH	'b'		/*@@@*/
-#define	FACE_MNR_MNSTR_LESSER_DEMON	'l'		/*@@@*/
-#define	FACE_MNR_MNSTR_GREATER_DEMON	'd'		/*@@@*/
+#define	FACE_MNR_MNSTR_LESSER_DEMON	'd'		/*@@@*/
+#define	FACE_MNR_MNSTR_GREATER_DEMON	'D'		/*@@@*/
 
 #endif	/* MNSTR_KIND_H */
