@@ -38,6 +38,9 @@ bool_t	chk_auto_door_mnstr_open( mnstr_t *p, long x, long y );
 bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y );
 void	set_flg_find_all_mnstr( void );
 bool_t	set_flg_find_mnstr( mnstr_t *p );
+bool_t	chk_flg_work_find_mbr( mnstr_t *p );
+void	set_flg_work_find_mbr( mnstr_t *p, bool_t flg );
+void	chk_boss_find_mbr( mnstr_t *p );
 void	chk_trap_all_mnstr( void );
 void	die_mnstr_drop_item( mnstr_t *p );
 void	die_mnstr( mnstr_t *p );
