@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-tab.h,v 1.5 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: mnstr-tab.h,v 1.6 2006/09/15 04:08:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_TAB_H
@@ -288,32 +288,32 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_SALAMANDER,	/*  */
 		+1, +5, },
+	{ MNSTR_KIND_UNDINE,	/*  */
+		+1, +5, },
 	{ MNSTR_KIND_MIMIC,	/* ˡʪ */
 		+1, +5, },
 	{ MNSTR_KIND_UNICORN,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_CYCLOPS,	/*  */
 		+1, +5, },
-	{ MNSTR_KIND_UNDINE,	/*  */
-		+1, +5, },
 	{ MNSTR_KIND_BANSHEE,	/* ǥå */
 		+1, +5, },
-	{ MNSTR_KIND_GNOME,	/*  */
-		+1, +5, },
 	{ MNSTR_KIND_SYLPH,	/*  */
 		+1, +5, },
+	{ MNSTR_KIND_GNOME,	/*  */
+		+1, +5, },
 	{ MNSTR_KIND_WYVERN,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_MEDUSA,	/* Ⱦ */
 		+1, +5, },
 	{ MNSTR_KIND_M_RED_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +1, },
 	{ MNSTR_KIND_M_BLUE_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +1, },
 	{ MNSTR_KIND_M_YELLOW_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +1, },
 	{ MNSTR_KIND_M_GREEN_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +1, },
 	{ MNSTR_KIND_WRAITH,	/* ǥå */
 		+1, +5, },
 	{ MNSTR_KIND_HYDRA,	/*  */
@@ -321,9 +321,9 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 	{ MNSTR_KIND_LESSER_DEMON,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_M_WHITE_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +3, },
 	{ MNSTR_KIND_M_BLACK_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +3, },
 	{ MNSTR_KIND_COCKATRICE,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_CERBERUS,	/*  */
@@ -331,11 +331,11 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 	{ MNSTR_KIND_VAMPIRE,	/* ǥå */
 		+1, +5, },
 	{ MNSTR_KIND_M_COPPER_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +2, },
 	{ MNSTR_KIND_M_SILVER_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +2, },
 	{ MNSTR_KIND_M_GOLD_DRAGON,	/* --ޥʡɥ饴 */
-		+1, +5, },
+		+1, +2, },
 	{ MNSTR_KIND_GORGON,	/*  */
 		+1, +5, },
 	{ MNSTR_KIND_EFREET,	/*  */
@@ -346,6 +346,14 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 		+1, +5, },
 	{ MNSTR_KIND_PHOENIX,	/*  */
 		+1, +5, },
+	{ MNSTR_KIND_SALAMANDER,	/*  */
+		+1, +DUN_MAX_LEV_BASE, },
+	{ MNSTR_KIND_UNDINE,	/*  */
+		+1, +DUN_MAX_LEV_BASE, },
+	{ MNSTR_KIND_SYLPH,	/*  */
+		+1, +DUN_MAX_LEV_BASE, },
+	{ MNSTR_KIND_GNOME,	/*  */
+		+1, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_HELLHOUND,	/*  */
 		+1, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_SPIRIT,	/* ǥå */
@@ -353,23 +361,23 @@ mnstr_lev_tab_t	mnstr_lev_tab[] = {
 	{ MNSTR_KIND_GREATER_DEMON,	/*  */
 		+1, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_RED_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_BLUE_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_YELLOW_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_GREEN_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_WHITE_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_BLACK_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_COPPER_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_SILVER_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	{ MNSTR_KIND_A_GOLD_DRAGON,	/* --󥷥ȡɥ饴 */
-		+1, +DUN_MAX_LEV_BASE, },
+		+3, +DUN_MAX_LEV_BASE, },
 	/**/
 
 	{ MNSTR_KIND_NULL,
