@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.172 2006/08/10 21:33:19 bowkenken Exp $
+* $Id: mnstr.c,v 1.176 2006/09/12 00:45:09 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -170,6 +170,8 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->y = MAP_DEL_Y;
 	mnstr->pre_x = MAP_DEL_X;
 	mnstr->pre_y = MAP_DEL_Y;
+	mnstr->pre_turn_x = MAP_DEL_X;
+	mnstr->pre_turn_y = MAP_DEL_Y;
 	mnstr->pre_draw_x = MAP_DEL_X;
 	mnstr->pre_draw_y = MAP_DEL_Y;
 	mnstr->dx = 1;
@@ -279,6 +281,7 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->work.towner_dy = 0;
 	mnstr->work.enter_door = NULL;
 	mnstr->work.dismissal_turn = 0;
+	mnstr->work.flg_used_energy_drain = FALSE;
 }
 
 /***************************************************************
@@ -1205,7 +1208,7 @@ bool_t	chk_auto_door_mnstr_break( mnstr_t *p, long x, long y )
 }
 
 /***************************************************************
-* ƤΥ󥹥ȯ֤ˤ
+* ƤΥ󥹥ȯ줿å
 ***************************************************************/
 
 void	set_flg_find_all_mnstr( void )
@@ -1223,9 +1226,9 @@ void	set_flg_find_all_mnstr( void )
 }
 
 /***************************************************************
-* 󥹥ȯ֤ˤ
+* 󥹥ȯ줿å
 * mnstr_t *p : 󥹥
-* return : ȯ֤ꤷ?
+* return : ȯ줿?
 ***************************************************************/
 
 bool_t	set_flg_find_mnstr( mnstr_t *p )
@@ -1245,10 +1248,20 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	if( chk_flg_or( p->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return FALSE;
 
+	/* ȯĴ٤ */
+
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
 	for( i = 0; i < MBR_MAX_N; i++ ){
+
+		/* ȯ? */
 		if( chk_find_chr( pty->mbr[i], p ) ){
+
+			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
+
+			/* ɸå */
+			chk_find_request_chr( p );
+
 			break;
 		}
 	}
