@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.h,v 1.33 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: mnstr.h,v 1.34 2006/02/23 17:58:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MNSTR_H
@@ -55,6 +55,27 @@
 /* 󥹥ɤݤȥСΥ٥뤬夬뤫ܰ */
 #define	EXP_NEED_KILL_MNSTR_N	20
 
+/* 󥹥ƥΨ */
+#define	ITEM_DROP_RATE_100	((rate_t)100)
+
+#define	ITEM_DROP_RATE_AAA	((rate_t)90)
+#define	ITEM_DROP_RATE_AA	((rate_t)80)
+#define	ITEM_DROP_RATE_A	((rate_t)70)
+
+#define	ITEM_DROP_RATE_BBB	((rate_t)60)
+#define	ITEM_DROP_RATE_BB	((rate_t)50)
+#define	ITEM_DROP_RATE_B	((rate_t)40)
+
+#define	ITEM_DROP_RATE_CCC	((rate_t)30)
+#define	ITEM_DROP_RATE_CC	((rate_t)20)
+#define	ITEM_DROP_RATE_C	((rate_t)10)
+
+#define	ITEM_DROP_RATE_DDD	((rate_t)5)
+#define	ITEM_DROP_RATE_DD	((rate_t)3)
+#define	ITEM_DROP_RATE_D	((rate_t)1)
+
+#define	ITEM_DROP_RATE_0	((rate_t)0)
+
 /***************************************************************
 * ǡ
 ***************************************************************/
