@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.27 2006/01/15 14:05:51 bowkenken Exp $
+* $Id: msg.c,v 1.29 2006/09/15 10:40:39 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -53,10 +53,12 @@
 # define	STR_LANG_NAME_ENGLISH	"English"
 # define	STR_LANG_NAME_JAPANESE_EUC	"Japanese"
 # define	STR_LANG_NAME_JAPANESE_UTF_8	"Japanese"
+# define	STR_LANG_NAME_JAPANESE_SJIS	"Japanese"
 #else	/* D_DOS */
 # define	STR_LANG_NAME_ENGLISH	"English"
 # define	STR_LANG_NAME_JAPANESE_EUC	"Japanese (EUC)"
 # define	STR_LANG_NAME_JAPANESE_UTF_8	"Japanese (UTF-8)"
+# define	STR_LANG_NAME_JAPANESE_SJIS	"Japanese (Shift-JIS)"
 #endif	/* D_DOS */
 
 /***************************************************************
@@ -102,6 +104,11 @@ static lang_t	lang_tab[LANG_TAB_MAX_N] = {
 		STR_LANG_NAME_JAPANESE_UTF_8,
 		LANG_KIND_JAPANESE_UTF_8,
 	},
+	{
+		"ja_JP.SJIS",
+		STR_LANG_NAME_JAPANESE_SJIS,
+		LANG_KIND_JAPANESE_SJIS,
+	},
 	{
 		NULL,
 		NULL,
@@ -127,15 +134,22 @@ static msg_t	all_lang_msg[LANG_KIND_MAX_N][N_MSG_MAX_N] = {
 #include	"msg-eng.h"
 	},
 	{
-#include	"msg-jpn.h"
+#ifdef	D_DOS
+# include	"msg-jpn-sjis.h"
+#else	/* D_DOS */
+# include	"msg-jpn.h"
+#endif	/* D_DOS */
 	},
 	{
 #ifdef	D_DOS
-# include	"msg-jpn.h"
+# include	"msg-jpn-sjis.h"
 #else	/* D_DOS */
 # include	"msg-jpn-utf8.h"
 #endif	/* D_DOS */
 	},
+	{
+#include	"msg-jpn-sjis.h"
+	},
 };
 
 /* åƤʤåѤΥǡ */
@@ -382,3 +396,135 @@ lang_kind_t	trans_lang_id_to_kind( char *id )
 	return LANG_KIND_JAPANESE_EUC;
 }
 
+/***************************************************************
+* ʸɽʸ֤
+* const char *s : ʸ
+* return : ʸ
+***************************************************************/
+
+long	str_len_draw( const char *s )
+{
+#ifdef	D_DOS
+
+	return( (long)strlen( s ) );
+
+#else	/* D_DOS */
+
+	switch( get_lang_kind() ){
+	case LANG_KIND_ENGLISH:
+		return str_len_draw_english( s );
+	case LANG_KIND_JAPANESE_EUC:
+		return str_len_draw_japanese_euc( s );
+	case LANG_KIND_JAPANESE_UTF_8:
+		return str_len_draw_japanese_utf_8( s );
+	case LANG_KIND_JAPANESE_SJIS:
+		return str_len_draw_japanese_sjis( s );
+	case LANG_KIND_MAX_N:
+		break;
+	}
+
+	return( (long)strlen( s ) );
+
+#endif	/* D_DOS */
+}
+
+/***************************************************************
+* Ѹʸɽʸ֤
+* const char *s : ʸ
+* return : ʸ
+***************************************************************/
+
+long	str_len_draw_english( const char *s )
+{
+	return( (long)strlen( s ) );
+}
+
+/***************************************************************
+* ܸ(EUC)ʸɽʸ֤
+* const char *s : ʸ
+* return : ʸ
+***************************************************************/
+
+long	str_len_draw_japanese_euc( const char *s )
+{
+	long	len;
+
+	for( len = 0; *s != '\0'; len++, s++ ){
+		unsigned char	c;
+
+		c = (unsigned char)*s;
+		if( (0x80 <= c) && (c <= 0x9f) )
+			len--;
+	}
+
+	return len;
+}
+
+/***************************************************************
+* ܸ(UTF-8)ʸɽʸ֤
+* const char *s : ʸ
+* return : ʸ
+***************************************************************/
+
+long	str_len_draw_japanese_utf_8( const char *s )
+{
+	long	len;
+	unsigned char	c;
+	long	skip_n;
+	long	i;
+
+	len = 0;
+	for( ; *s != '\0'; s++ ){
+		c = (unsigned char)*s;
+		skip_n = 0;
+
+		if( (c & 0x80) == 0x00 ){
+			len++;
+			continue;
+		} else if( (c & 0xe0) == 0xc0 ){
+			skip_n = 2;
+		} else if( (c & 0xf0) == 0xe0 ){
+			skip_n = 3;
+		} else if( (c & 0xf8) == 0xf0 ){
+			skip_n = 4;
+		} else if( (c & 0xfc) == 0xf8 ){
+			skip_n = 5;
+		} else if( (c & 0xfe) == 0xfc ){
+			skip_n = 6;
+		}
+
+		len += 2;
+		s++;
+		for( i = 1; i < skip_n; i++ ){
+			if( *s == '\0' ){
+				s--;
+				break;
+			}
+			if( (c & 0xc0) != 0x80 ){
+				s--;
+				break;
+			}
+
+			s++;
+		}
+	}
+
+	return len;
+}
+
+/***************************************************************
+* ܸ(Shift-JIS)ʸɽʸ֤
+* const char *s : ʸ
+* return : ʸ
+***************************************************************/
+
+long	str_len_draw_japanese_sjis( const char *s )
+{
+	long	len;
+
+	for( len = 0; *s != '\0'; len++, s++ )
+		;
+
+	return len;
+}
+
