@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.172 2006/08/10 21:33:19 bowkenken Exp $
+* $Id: party.c,v 1.174 2006/09/10 23:53:46 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -1127,6 +1127,8 @@ void	new_mbr(
 	mbr->y = MAP_DEL_Y;
 	mbr->pre_x = MAP_DEL_X;
 	mbr->pre_y = MAP_DEL_Y;
+	mbr->pre_turn_x = MAP_DEL_X;
+	mbr->pre_turn_y = MAP_DEL_Y;
 	mbr->pre_draw_x = MAP_DEL_X;
 	mbr->pre_draw_y = MAP_DEL_Y;
 	mbr->dx = 1;
@@ -1248,6 +1250,7 @@ void	new_mbr(
 	mbr->work.towner_dy = 0;
 	mbr->work.enter_door = NULL;
 	mbr->work.dismissal_turn = 0;
+	mbr->work.flg_used_energy_drain = FALSE;
 
 	set_chr_id( mbr, get_ls_mbr(), LS_MBR_MAX_N );
 
