@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.51 2006/01/15 14:05:51 bowkenken Exp $
+* $Id: pet.c,v 1.52 2006/08/20 12:18:10 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -640,13 +640,12 @@ bool_t	dismissal( pet_t *p )
 
 	not_join_pet( p );
 
-	for( i = 0; i < PET_MAX_N; i++ ){
-		if( party_pet[i] == p ){
+	for( i = 0; i < PET_MAX_N; i++ )
+		if( party_pet[i] == p )
 			party_pet[i] = NULL;
-			break;
-		}
-	}
+
 	die_chr( p, FALSE, FALSE, FALSE );
+	p->stat |= (FLG_STAT_NOT_EXIST | FLG_STAT_DEAD);
 
 	return TRUE;
 }
