@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.90 2006/08/10 21:33:19 bowkenken Exp $
+* $Id: request.c,v 1.92 2006/08/20 12:18:10 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -38,7 +38,7 @@
 /***************************************************************/
 
 /* ǥХå뤫? */
-#if	0
+#if	1
 # define	FLG_DEBUG_REQUEST	1
 #else
 # define	FLG_DEBUG_REQUEST	0
@@ -1760,6 +1760,86 @@ bool_t	chr_contract_request(
 	return TRUE;
 }
 
+/***************************************************************
+* ɸΥ饯ȯΰؤαƶå
+* chr_t *chr : ȯ줿饯
+***************************************************************/
+
+void	chk_find_request_chr( chr_t *chr )
+{
+	request_t	*req;
+	pet_t	*npc;
+	mbr_t	*mbr;
+	char	*msg_fema, *msg_male;
+
+	if( chr == NULL )
+		return;
+
+	/* Ƥ뤫? */
+
+	req = chr->work.request;
+	if( req == NULL )
+		return;
+	if( !req->flg_contract )
+		return;
+	if( !req->flg_contract_mbr )
+		return;
+
+	/* ȯ饯ܿͤä̤ */
+
+	npc = get_npc_request( req );
+	if( (npc != NULL) && cmp_chr( npc, chr ) )
+		return;
+
+	mbr = get_mbr_randm( MAP_DEL_X, MAP_DEL_Y );
+	if( mbr == NULL )
+		return;
+
+	switch( req->kind ){
+	case REQUEST_KIND_NULL:
+		break;
+	case REQUEST_KIND_RARE_GOODS:
+		break;
+	case REQUEST_KIND_TAME_MNSTR:
+		msg_fema = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_FEMALE;
+		msg_male = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_MALE;
+
+		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		break;
+	case REQUEST_KIND_RESCUE:
+		msg_fema = MSG_WORDS_REQUEST_RESCUE_FIND_FEMALE;
+		msg_male = MSG_WORDS_REQUEST_RESCUE_FIND_MALE;
+
+		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		break;
+	case REQUEST_KIND_TOUR_GUIDE:
+		break;
+	case REQUEST_KIND_EXTERMINATE:
+		break;
+	case REQUEST_KIND_REVENGE:
+		msg_fema = MSG_WORDS_REQUEST_REVENGE_FIND_FEMALE;
+		msg_male = MSG_WORDS_REQUEST_REVENGE_FIND_MALE;
+
+		print_words( cv_idx_to_client_name( req ),
+				req->client_sex,
+				msg_fema,
+				msg_male,
+				cv_idx_to_mnstr_name( req ) );
+		break;
+	case REQUEST_KIND_WANTED_CRIMINAL:
+		msg_fema = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_FEMALE;
+		msg_male = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_MALE;
+
+		print_words( mbr->name, mbr->sex.cur,
+				msg_fema,
+				msg_male,
+				cv_idx_to_mnstr_name( req ) );
+		break;
+	case REQUEST_KIND_MAX_N:
+		break;
+	}
+}
+
 /***************************************************************
 * 
 * request_t *req : 
@@ -1820,33 +1900,35 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	if( chr == NULL )
 		return;
 
+	req = chr->work.request;
+	if( req == NULL )
+		return;
+
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_TOUR_GUIDE, FALSE );
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_EXTERMINATE, TRUE );
 
-	req = chr->work.request;
-	if( req != NULL ){
-		switch( req->kind ){
-		case REQUEST_KIND_NULL:
-		case REQUEST_KIND_RARE_GOODS:
-		case REQUEST_KIND_TAME_MNSTR:
-		case REQUEST_KIND_RESCUE:
-		case REQUEST_KIND_TOUR_GUIDE:
-		case REQUEST_KIND_EXTERMINATE:
-			break;
-		case REQUEST_KIND_REVENGE:
-			chk_finish_request_revenge( req, chr );
-			break;
-		case REQUEST_KIND_WANTED_CRIMINAL:
-			chk_finish_request_wanted_criminal( req );
-			break;
-		case REQUEST_KIND_MAX_N:
-			break;
-		}
+	switch( req->kind ){
+	case REQUEST_KIND_NULL:
+		break;
+	case REQUEST_KIND_RARE_GOODS:
+		put_request_rare_goods( chr );
+		break;
+	case REQUEST_KIND_TAME_MNSTR:
+	case REQUEST_KIND_RESCUE:
+	case REQUEST_KIND_TOUR_GUIDE:
+	case REQUEST_KIND_EXTERMINATE:
+		break;
+	case REQUEST_KIND_REVENGE:
+		chk_finish_request_revenge( req, chr );
+		break;
+	case REQUEST_KIND_WANTED_CRIMINAL:
+		chk_finish_request_wanted_criminal( req );
+		break;
+	case REQUEST_KIND_MAX_N:
+		break;
 	}
-
-	put_request_rare_goods( chr );
 }
 
 /***************************************************************
@@ -1990,6 +2072,8 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 		return FALSE;
 
 	npc = get_npc_request( req );
+	if( npc == NULL )
+		return FALSE;
 	if( cmp_chr( npc, chr ) )
 		return FALSE;
 
@@ -2452,10 +2536,12 @@ char	*set_menu_request(
 		sprintf( ls[k].path, "/request/%ld", i );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 				MENU_KIND_MAX_LEN );
-		ls[k].accel_key = (char)('A' + (n % MENU_REQUEST_N_PER_PAGE));
+		ls[k].accel_key = (char)('A'
+				+ (n % MENU_REQUEST_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, g_request[i].heading, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, g_request[i].heading,
+				MENU_MSG_MAX_LEN );
 		ls[k].call_back = cb;
 		ls[k].arg = &(g_request[i]);
 		ls[k].flg = FLG_NULL;
@@ -2465,7 +2551,8 @@ char	*set_menu_request(
 		if( ((n % MENU_REQUEST_N_PER_PAGE) == 0) && !flg_mbr ){
 			str_nz_cpy( ls[k].path, "/request/Refresh",
 					MENU_PATH_MAX_LEN );
-			str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+			str_nz_cpy( ls[k].kind, "<Branch>",
+					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
