@@ -69,11 +69,10 @@ void	chr_cast_spell_sub(
 	spell_tab_t *tab, rate_t rate,
 	long x, long y, trgt_kind_t trgt_kind, void *p
 );
-bool_t	chk_spell(
-	chr_t *o_p, chr_t *d_p,
-	spell_tab_t *tab, bool_t flg_item
-);
+bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item );
 bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt );
+bool_t	chk_bar_limit( chr_t *chr );
+bool_t	chk_bar_limit_lev( chr_t *chr );
 bool_t	chk_can_chr_cast( chr_t *chr, spell_kind_t kind );
 bool_t	chk_chr_learned_spell( chr_t *chr, spell_kind_t kind );
 bool_t	set_chr_learned_spell( chr_t *chr, spell_kind_t kind, bool_t flg );
