@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.12 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: spell-tab.h,v 1.13 2006/02/17 04:45:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -93,6 +93,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/MAG/store_light",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_STORE_LIGHT, "",
+		cb_menu_spell, (void *)SPELL_KIND_STORE_LIGHT,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/MAG/teleport_party",
 		"<Branch>",
