@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.149 2006/08/12 04:22:56 bowkenken Exp $
+* $Id: spell.c,v 1.150 2006/09/10 23:53:46 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -1745,6 +1745,15 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_ENERGY_DRAIN:
 		fx_energy_drain( (chr_t *)p, FALSE );
+
+		if( chr->kind != CHR_KIND_MNSTR )
+			break;
+		if( is_pet( chr ) )
+			break;
+		if( ((chr_t *)p)->kind != CHR_KIND_MBR )
+			break;
+		chr->work.flg_used_energy_drain = TRUE;
+
 		break;
 	case SPELL_KIND_SLOW:
 		fx_speed_up( chr, (chr_t *)p, -1, FX_AVE_TURN_SPEED_DOWN );
