@@ -32,18 +32,18 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shop_buy( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shop_sale_item( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shop_sale_equip( menu_t **pp, menu_t **dflt );
-bool_t	menu_shop_buy(
+long	menu_shop_buy(
 	shop_n_t g_shop_n, mbr_t *g_sel_mbr, item_t *item
 );
-bool_t	menu_shop_sale_item(
+long	menu_shop_sale_item(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item
 );
-bool_t	menu_shop_sale_equip(
+long	menu_shop_sale_equip(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item
 );
-bool_t	menu_shop_sale(
+long	menu_shop_sale(
 	shop_n_t shop_n, mbr_t *mbr, item_t *item,
-	deal_kind_t deal_kind
+	deal_kind_t deal_kind, bool_t flg_auto_sale
 );
 item_t	*get_begin_article(
 	mbr_t *mbr, shop_n_t shop_n, deal_kind_t kind
@@ -53,6 +53,7 @@ bool_t	chk_end_article( item_t *art, item_t *art_head, deal_kind_t kind );
 bool_t	chk_deal_article(
 	item_t *art, shop_n_t shop_n, deal_kind_t deal_kind
 );
+shop_n_t	get_shop_deal_article( item_t *art, deal_kind_t deal_kind );
 char	*menu_bar( void );
 char	*cb_menu_bar_order( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt );
@@ -69,7 +70,9 @@ char	*cb_menu_bar_edit_mbr_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_data_form( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt );
-char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt );
+char	*cb_menu_bar_arrange_top( menu_t **pp, menu_t **dflt );
+char	*cb_menu_bar_arrange_bottom( menu_t **pp, menu_t **dflt );
+char	*cb_menu_bar_arrange( long d );
 char	*cb_menu_bar_new_mbr( menu_t **pp, menu_t **dflt );
 bool_t	exec_menu_new_mbr( void );
 char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt );
@@ -77,7 +80,8 @@ char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_edit_class( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_edit_class_sub( menu_t **pp, menu_t **dflt );
 char	*menu_edit_class( long n );
-char	*cb_menu_bar_arrange_class( menu_t **pp, menu_t **dflt );
+char	*cb_menu_bar_arrange_top_class( menu_t **pp, menu_t **dflt );
+char	*cb_menu_bar_arrange_bottom_class( menu_t **pp, menu_t **dflt );
 char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt );
 char	*menu_new_class( long n );
 long	exec_edit_class( class_t *org, bool_t flg_new );
@@ -110,9 +114,14 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt );
 char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_town_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_navi( menu_t **pp, menu_t **dflt );
 char	*cb_menu_navi_stairs( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_sale( menu_t **pp, menu_t **dflt );
+bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr );
+char	*cb_menu_auto_sale_chk( menu_t **pp, menu_t **dflt );
+char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt );
 
 #ifdef __cplusplus
 }
