@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.16 2006/02/17 04:45:36 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.18 2006/08/09 20:50:34 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -1656,12 +1656,21 @@ menu_t	ls_menu_bar_edit_mbr_sub[] = {
 		FLG_NULL,
 	},
 	{
-		"/edit member/arrange",
+		"/edit member/arrange top",
 		"<Item>",
-		'A',
+		'T',
 		"",
-		N_MSG_MENU_BAR_ARRANGE, "",
-		cb_menu_bar_arrange, NULL,
+		N_MSG_MENU_BAR_ARRANGE_TOP, "",
+		cb_menu_bar_arrange_top, NULL,
+		FLG_NULL,
+	},
+	{
+		"/edit member/arrange bottom",
+		"<Item>",
+		'B',
+		"",
+		N_MSG_MENU_BAR_ARRANGE_BOTTOM, "",
+		cb_menu_bar_arrange_bottom, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1704,12 +1713,21 @@ menu_t	ls_menu_bar_sel_edit_class[] = {
 		FLG_NULL,
 	},
 	{
-		"/select edit class/arrange",
+		"/select edit class/arrange top",
 		"<Item>",
-		'A',
+		'T',
 		"",
-		N_MSG_MENU_BAR_ARRANGE_CLASS, "",
-		cb_menu_bar_arrange_class, NULL,
+		N_MSG_MENU_BAR_ARRANGE_TOP_CLASS, "",
+		cb_menu_bar_arrange_top_class, NULL,
+		FLG_NULL,
+	},
+	{
+		"/select edit class/arrange bottom",
+		"<Item>",
+		'B',
+		"",
+		N_MSG_MENU_BAR_ARRANGE_BOTTOM_CLASS, "",
+		cb_menu_bar_arrange_bottom_class, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1877,5 +1895,6 @@ menu_t	ls_menu_pet_shop_buy[
 	1 + 1 + PET_SHOP_PET_MAX_N + PET_SHOP_PAGE_MAX_N + 1];
 
 menu_t	ls_menu_navi[1 + 1 + SHOP_N_MAX_N + 1];
+menu_t	ls_menu_auto_sale[1 + 1 + MBR_ITEM_MAX_N + 1 + 1];
 
 #endif	/* TMENU_TAB_H */
