@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.99 2006/08/10 21:33:19 bowkenken Exp $
+* $Id: tmenu.c,v 1.103 2006/09/10 23:53:46 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -49,7 +49,9 @@
 		((LS_MBR_MAX_N + LS_MBR_MAX_N_PER_PAGE - 1)\
 		/ LS_MBR_MAX_N_PER_PAGE)
 
-#define	ORDER_MILK_LEV	20
+#define	ORDER_MILK_MAX_LEV	100
+#define	ORDER_MILK_MIN_RATE	((rate_t)1)
+#define	ORDER_MILK_MAX_RATE	((rate_t)_100_PERCENT)
 
 /**/
 
@@ -593,7 +595,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 	}
 
 	if( flg_rumor )
-		hear_rumor();
+		hear_rumor( g_shop_n );
 
 	return "/order";
 }
@@ -602,6 +604,10 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 
 bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 {
+	long	lev;
+	rate_t	rate;
+	sex_t	sex;
+
 	if( mbr == NULL )
 		return FALSE;
 	if( item == NULL )
@@ -609,16 +615,36 @@ bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item )
 
 	if( mbr->sex.cur != MALE )
 		return FALSE;
-	if( get_specialist_lev( mbr ) >= ORDER_MILK_LEV )
-		return FALSE;
 	if( shop_n != SHOP_N_BAR )
 		return FALSE;
 	if( item->dat.potion.kind != POTION_KIND_MILK )
 		return FALSE;
 
-	print_words( MSG_NPC_NAME_BAR_CUSTOMER, MALE,
-			MSG_WORDS_MALE_ORDER_MILK,
-			MSG_WORDS_MALE_ORDER_MILK );
+	/* ФΨ */
+
+	lev = get_specialist_lev( mbr );
+	rate = ORDER_MILK_MAX_LEV - lev;
+
+	if( rate < ORDER_MILK_MIN_RATE )
+		rate = ORDER_MILK_MIN_RATE;
+	if( rate > ORDER_MILK_MAX_RATE )
+		rate = ORDER_MILK_MAX_RATE;
+
+	/* Ф뤫 */
+
+	if( !rate_randm( rate ) )
+		return FALSE;
+
+	/* Ф */
+
+	if( rate_randm( (rate_t)50 ) )
+		sex = FEMALE;
+	else
+		sex = MALE;
+
+	print_words( MSG_NPC_NAME_BAR_CUSTOMER, sex,
+			MSG_WORDS_ORDER_MILK_FEMALE,
+			MSG_WORDS_ORDER_MILK_MALE );
 
 	return TRUE;
 }
@@ -3597,7 +3623,7 @@ char	*cb_menu_navi( menu_t **pp, menu_t **dflt )
 {
 	g_navi_dflt = *pp;
 
-	navi_party( (shop_n_t)((*pp)->arg) );
+	navi_party( (shop_n_t)(long)((*pp)->arg) );
 
 	return NULL;
 }
