@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town-tab.h,v 1.4 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: town-tab.h,v 1.8 2006/01/12 08:51:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TOWN_TAB_H
@@ -338,6 +338,16 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		NECKLACE_KIND_NULL,
 	},
 
+	{ ITEM_KIND_POTION, 12,
+		POTION_KIND_SENSE_INVISIBLE,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_POTION, 12,
 		POTION_KIND_RESI_PHYS,
 		SCROLL_KIND_NULL,
@@ -468,6 +478,16 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		NECKLACE_KIND_NULL,
 	},
 
+	{ ITEM_KIND_SCROLL, 50,
+		POTION_KIND_NULL,
+		SCROLL_KIND_IDENTIFY_ALL_ITEM,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
 		SCROLL_KIND_DETECT_ITEM,
@@ -1435,6 +1455,15 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_RESI_STAT_PASSWALL,
 		NECKLACE_KIND_NULL,
 	},
+	{ ITEM_KIND_ACCE, 3,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_RESI_STAT_SENSE_INVISIBLE,
+		NECKLACE_KIND_NULL,
+	},
 /* necklace */
 	{ ITEM_KIND_ACCE, 3,
 		POTION_KIND_NULL,
