@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.118 2006/02/24 14:39:37 bowkenken Exp $
+* $Id: town.c,v 1.122 2006/09/12 01:25:21 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1666,8 +1666,8 @@ void	stay_inn( bool_t flg_short_stay )
 
 	if( chk_discount() ){
 		print_words( MSG_NPC_NAME_INN_LANDLORD, MALE,
-				MSG_WORDS_DISCOUNT_DAY,
-				MSG_WORDS_DISCOUNT_DAY,
+				MSG_WORDS_DISCOUNT_DAY_FEMALE,
+				MSG_WORDS_DISCOUNT_DAY_MALE,
 				get_shop_name( g_discount_queue.shop_n ) );
 	}
 }
@@ -2647,13 +2647,16 @@ void	set_map_glow( long dx, long dy, bool_t flg_morning )
 
 /**/
 
-void	hear_rumor( void )
+void	hear_rumor( shop_n_t shop_n )
 {
 	sex_t	sex;
 	long	latest_n, randm_n, tab_n;
 	long	n;
 	long	i;
 
+	if( shop_n != SHOP_N_BAR )
+		return;
+
 	if( per_randm( 2 ) )
 		sex = FEMALE;
 	else
