@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.55 2006/08/10 21:33:19 bowkenken Exp $
+* $Id: trap.c,v 1.57 2006/09/15 09:38:44 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -42,17 +42,18 @@
 #define	TRAP_DIFFICULTY_LEV_RATE	RATE_LEV_PER_DUN_LEV
 #define	TRAP_DIFFICULTY_LEV_ADD	1
 
-/* ȥåνиΨ */
+/* ȥå */
 
 /* и㳬 */
 #define	TRAP_ROOM_DUN_LEV_MIN_N	30
 /* иΨ */
 #define	TRAP_ROOM_RATE	((rate_t)3)
-/* ˻ųݤƤ */
-#define	TRAP_ROOM_N	50
+/* ųݤƤ */
+#define	TRAP_ROOM_N	32
 
-/* Υ᡼( HP  %) */
+/* Υ᡼ */
 
+/*  HP  % */
 #define	PIT_DAM_RATE	((rate_t)25)
 #define	PIT_DAM_ADD	1
 
@@ -266,6 +267,15 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 	return NULL;
 }
 
+/***************************************************************
+* ꤷ櫤Ϥ
+* trap_kind_t kind : 櫤μ
+* long x : X ɸ
+* long y : Y ɸ
+* long dun_lev : µܥ٥
+* return : Ϥä
+***************************************************************/
+
 trap_t	*make_trap_std( trap_kind_t kind, long x, long y, long dun_lev )
 {
 	long	tab_n;
@@ -299,7 +309,7 @@ trap_t	*make_trap_std( trap_kind_t kind, long x, long y, long dun_lev )
 }
 
 /***************************************************************
-* ɸŪ櫤Ϥ
+* ƺѤߤΥ櫤Ϥ
 * long dun_lev : µܥ٥
 * trap_t *trap : 
 * long tab_n : ǡơ֥Υǥå
@@ -434,13 +444,16 @@ void	make_chk_trap_room( long dun_lev )
 void	make_trap_room( long area_x, long area_y, long dun_lev )
 {
 	dun_t	*dun = get_dun();
+	trap_t	*trap;
+	long	item_n, item_max_n;
+	long	mx, my;
 	long	n;
 	long	i;
 
 	n = 0;
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
-		long	mx, my;
-		trap_t	*trap;
+		if( n >= TRAP_ROOM_N )
+			break;
 
 		mx = area_x * AREA_MAX_X + randm( AREA_MAX_X );
 		my = area_y * AREA_MAX_Y + randm( AREA_MAX_Y );
@@ -451,8 +464,18 @@ void	make_trap_room( long area_x, long area_y, long dun_lev )
 		trap = make_trap( mx, my, dun_lev );
 		if( trap != NULL )
 			n++;
-		if( n >= TRAP_ROOM_N )
+	}
+
+	item_n = 0;
+	item_max_n = roll_dice( DUN_ITEM_TRAP_ROOM_AVE_N, TRUE );
+	for( i = 0; i < LOOP_MAX_10000; i++ ){
+		if( item_n >= item_max_n )
 			break;
+
+		mx = area_x * AREA_MAX_X + randm( AREA_MAX_X );
+		my = area_y * AREA_MAX_Y + randm( AREA_MAX_Y );
+		if( make_item( mx, my, dun->lev ) != ITEM_KIND_NULL )
+			item_n++;
 	}
 }
 
@@ -483,9 +506,9 @@ void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 }
 
 /***************************************************************
-* 櫤Ĵ٤
+* 饯櫤˳ݤäĴ٤
 * chr_t *chr : Ĵ٤륭饯
-* chr_t *thief : Ĵ٤Τ򥵥ݡȤ륭饯
+* chr_t *thief : 櫤β򥵥ݡȤ륭饯
 ***************************************************************/
 
 void	chk_trap( chr_t *chr, chr_t *thief )
@@ -502,8 +525,8 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 	if( !chk_can_act_chr( chr ) )
 		return;
 
-	if( chr->x == chr->pre_x )
-		if( chr->y == chr->pre_y )
+	if( chr->x == chr->pre_turn_x )
+		if( chr->y == chr->pre_turn_y )
 			return;
 
 	if( thief == NULL )
@@ -523,10 +546,14 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 			find_trap( trap );
 	}
 
-	if( chr_roll( thief, ABL_KIND_THI, ABL_KIND_AGI, trap->difficulty ) )
+	if( chr_roll( thief, ABL_KIND_THI, ABL_KIND_AGI,
+			trap->difficulty ) ){
+		curs_attrset_chr( chr, +1, FALSE );
 		print_msg_mbr( chr, FLG_NULL, MSG_NOT_TRAPPED, chr->name );
-	else
+		curs_attrset_dflt();
+	} else {
 		caught_trap( trap, chr );
+	}
 }
 
 /***************************************************************
@@ -574,8 +601,10 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	}
 
 	if( trap->tab->flg_draw_msg ){
+		curs_attrset_chr( chr, -1, FALSE );
 		print_msg_mbr( chr, FLG_NULL, MSG_TRAPPED,
 				chr->name, trap->tab->name );
+		curs_attrset_dflt();
 	}
 
 	g_dmy_chr.kind = CHR_KIND_NULL;
