@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.h,v 1.28 2006/01/12 08:51:38 bowkenken Exp $
+* $Id: trap.h,v 1.30 2006/09/10 23:53:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TRAP_H
@@ -54,7 +54,7 @@
 
 #if	0
 # ifndef	D_TEST_TRAP_KIND
-#  define	D_TEST_TRAP_KIND	TRAP_KIND_ARW
+#  define	D_TEST_TRAP_KIND	TRAP_KIND_CHUTE
 # endif
 #endif
 
