@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2004 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2006 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,59 +25,26 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: turn.c,v 1.31 2004/12/06 06:18:18 bowkenken Exp $
+* $Id: turn.c,v 1.37 2006/01/15 15:16:09 bowkenken Exp $
 ***************************************************************/
 
-#include	"gmain.h"
-#include	"misc.h"
-#include	"turn.h"
-/*#include	"dun.h"*/
-#include	"town.h"
-#include	"item.h"
-/*#include	"spell.h"*/
-/*#include	"chr.h"*/
-#include	"party.h"
-#include	"mnstr.h"
-#include	"pet.h"
-/*#include	"fight.h"*/
-#include	"fx.h"
-/*#include	"trap.h"*/
-#include	"draw.h"
-/*#include	"curs.h"*/
-#include	"menu.h"
-/*#include	"amenu.h"*/
-#include	"request.h"
-/*#include	"gfile.h"*/
-#include	"msg.h"
-/*#include	"ver.h"*/
-/*#include	"gmain-prot.h"*/
-#include	"misc-prot.h"
-#include	"turn-prot.h"
-/*#include	"dun-prot.h"*/
-#include	"town-prot.h"
-#include	"item-prot.h"
-/*#include	"spell-prot.h"*/
-/*#include	"chr-prot.h"*/
-/*#include	"party-prot.h"*/
-#include	"mnstr-prot.h"
-/*#include	"pet-prot.h"*/
-/*#include	"fight-prot.h"*/
-#include	"fx-prot.h"
-/*#include	"trap-prot.h"*/
-#include	"draw-prot.h"
-/*#include	"curs-prot.h"*/
-/*#include	"menu-prot.h"*/
-/*#include	"tmenu-prot.h"*/
-/*#include	"amenu-prot.h"*/
-#include	"request-prot.h"
-/*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+/***************************************************************
+* 
+***************************************************************/
 
-/**/
+#define	TURN_C
+#include	"inc.h"
+
+/***************************************************************
+* ѿ
+***************************************************************/
 
 static long	g_day, g_turn;
 
-/**/
+/***************************************************************
+* ν
+* return : 
+***************************************************************/
 
 long	init_turn()
 {
@@ -87,7 +54,11 @@ long	init_turn()
 	return g_turn;
 }
 
-/**/
+/***************************************************************
+* ꤷƥꥻå
+* long n : ꤹ륿
+* return : 
+***************************************************************/
 
 long	reset_turn( long n )
 {
@@ -105,7 +76,11 @@ long	reset_turn( long n )
 	return g_turn;
 }
 
-/**/
+/***************************************************************
+* ʤ
+* long n : ʤ륿
+* return : 
+***************************************************************/
 
 long	add_turn( long n )
 {
@@ -120,7 +95,10 @@ long	add_turn( long n )
 	return ret;
 }
 
-/**/
+/***************************************************************
+*  1 Ŀʤ
+* return : 
+***************************************************************/
 
 long	inc_turn( void )
 {
@@ -140,21 +118,31 @@ long	inc_turn( void )
 	return g_turn;
 }
 
-/**/
+/***************************************************************
+* 
+* long n : ꤹ륿
+* return : 
+***************************************************************/
 
 long	set_turn( long n )
 {
 	return reset_turn( n );
 }
 
-/**/
+/***************************************************************
+* ֤
+* return : 
+***************************************************************/
 
 long	get_turn( void )
 {
 	return g_turn;
 }
 
-/**/
+/***************************************************************
+* դꤷƥꥻå
+* return : 
+***************************************************************/
 
 long	reset_day( void )
 {
@@ -164,7 +152,10 @@ long	reset_day( void )
 	return g_day;
 }
 
-/**/
+/***************************************************************
+* դ 1 ʤ
+* return : 
+***************************************************************/
 
 long	inc_day( void )
 {
@@ -173,12 +164,18 @@ long	inc_day( void )
 	inc_day_all_fx();
 
 	chk_request_limit();
-	chk_request_contract();
+	chk_request_npc_contract();
 
 	return g_day;
 }
 
-/**/
+/***************************************************************
+* ǯդ
+* long year : ǯ
+* long month : 
+* long day : 
+* return : 
+***************************************************************/
 
 long	set_game_date( long year, long month, long day )
 {
@@ -190,7 +187,11 @@ long	set_game_date( long year, long month, long day )
 	return g_day;
 }
 
-/**/
+/***************************************************************
+* դ
+* long day : 
+* return : 
+***************************************************************/
 
 long	set_game_day( long day )
 {
@@ -199,14 +200,20 @@ long	set_game_day( long day )
 	return g_day;
 }
 
-/**/
+/***************************************************************
+* դ֤
+* return : 
+***************************************************************/
 
 long	get_game_day( void )
 {
 	return g_day;
 }
 
-/**/
+/***************************************************************
+* ߤΥνФĴ٤
+* return : νФ?
+***************************************************************/
 
 bool_t	chk_morning( void )
 {
@@ -222,7 +229,10 @@ bool_t	chk_morning( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ߤΥ꤫Ĵ٤
+* return : ꤫?
+***************************************************************/
 
 bool_t	chk_evening( void )
 {
@@ -238,7 +248,10 @@ bool_t	chk_evening( void )
 	return TRUE;
 }
 
-/**/
+/***************************************************************
+* ߤΥ뤫Ĵ٤
+* return : 뤫?
+***************************************************************/
 
 bool_t	chk_night( void )
 {
@@ -257,7 +270,10 @@ bool_t	chk_night( void )
 	return FALSE;
 }
 
-/**/
+/***************************************************************
+* ߤΥΥʸ֤
+* return : ʸ
+***************************************************************/
 
 char	*get_calendar_str( void )
 {
@@ -281,7 +297,10 @@ char	*get_calendar_str( void )
 	return s;
 }
 
-/**/
+/***************************************************************
+* ߤΥΥơѥʸ֤
+* return : ơѥʸ
+***************************************************************/
 
 char	*get_stat_time_str( void )
 {
@@ -298,7 +317,10 @@ char	*get_stat_time_str( void )
 	return s;
 }
 
-/**/
+/***************************************************************
+* ߤΥʸ֤
+* return : ʸ֤
+***************************************************************/
 
 char	*get_day_of_week_name( void )
 {
@@ -324,12 +346,13 @@ char	*get_day_of_week_name( void )
 	return MSG_NULL;
 }
 
-/**/
+/***************************************************************
+* ߤ֤
+* return : 
+***************************************************************/
 
 day_of_week_t	get_day_of_week( void )
 {
-	return( get_game_day() % DAY_OF_WEEK_MAX_N );
+	return( (day_of_week_t)(get_game_day() % DAY_OF_WEEK_MAX_N) );
 }
 
-/**/
-
